@@ -1,6 +1,15 @@
 import numpy as np
-from cv2 import (CHAIN_APPROX_NONE, LINE_AA, RETR_EXTERNAL, SVDecomp,
-                 boundingRect, circle, drawContours, findContours, line)
+from cv2 import (
+    CHAIN_APPROX_NONE,
+    LINE_AA,
+    RETR_EXTERNAL,
+    SVDecomp,
+    boundingRect,
+    circle,
+    drawContours,
+    findContours,
+    line,
+)
 from cv2 import moments as cv2_moments
 
 from .debug_utils import cCOLOURS, debug_show
